//*** Stata 9 Dofile for "Who Said What? Message Source Cues Moderate Framing Effects"
// Questionnaire Version: 1 - 8, N=533
// Experiment 1: One-framed Information Flows
// ver = 1 (A, Liberal Source - Free Speech Frame)
// ver = 2 (B, Liberal Source - Public Order Frame)
// ver = 3 (C, Conservative Source - Free Speech Frame)
// ver = 4 (D, Conservative Sournce - Public Order Frame)
// Experiment 2: Two-framed Information Flows
// ver = 5 (E, Liberal Source - Free Speech Frame AND Conservative - Public Order Frame)
// ver = 6 (F, Conservative Source - Free Speech Frame AND Liberal Source - Public Order Frame)
// ver = 7 (G, Conservative Source - Public Order Frame AND Liberal Source - Free Speech Frame)
// ver = 8 (H, Liberal Source - Public Order Frame AND Conservative Source - Free Speech Frame) 

// Dofile for Stata 9
version 9

// Analysis for Experiment 2 ONLY
drop if ver < 5

//*** INDEPENDENT VARIABLES

// [LPO_CFS] Centered on Liberal-PO Frame, Conservative-FS Frame
// 0 = Liberal-Public Order, Conservative-Free Speech,  1 = Liberal-Free Speech, Conservative-Public Order
gen lpo_cfs = 999
recode lpo_cfs (999=0) if ver==6 | ver==8
recode lpo_cfs (999=1) if ver==5 | ver==7
sum lpo_cfs, det
tab lpo_cfs

// [LFS_CPO] Centered on Liberal-FS Frame, Conservative-PO Frame
recode lpo_cfs (1=0)(0=1), gen(lfs_cpo)
tab lfs_cpo

// [LORDER] Order Effects Centered on Liberal cue presented first
//gen lorder = 999
//recode lorder (999=0) if ver==5 | ver==8
//recode lorder (999=1) if ver==6 | ver==7
//tab lorder
// [CORDER] Order Effects Centered on Liberal cue presented first
//recode lorder (1=0)(0=1), gen(corder)
//tab corder

// [THERM] Mean-Centered Con-Lib Thermometer, Higher #'s = More Conservative
gen th = (gaff2 - gaff1)/8
tab th
gen the = (th + 1)/2
tab the
egen theM = mean(the)
sum theM
gen therm = the - theM
sum therm, detail

// [THERML] Con-Lib Therm Centered at Min (Very Warm Toward Liberals)
tab the
gen thermL = the

// [THERMH] Con-Lib Therm Centered at Max (Very Warm Toward Conservatives)
tab the
gen thermH = the - 1
tab thermH

//*** DEPENDENT VARIABLES
// [VALUE1-3]: Value Importance 0 = Completely Unimportant, 1 = Extremely Important (7-point scale ranges from 0-1)
gen value1 = (val1-1)/6
gen value2 = (val2-1)/6
gen value3 = (val3-1)/6
sum value1-value3, det

// [DVRALLY]: Dependent Variable, Support for KKK Rally, 0 = Do NOT Support, 1 = Completely Support
tab rally
recode rally (1=9)(2=8)(3=7)(4=6)(5=5)(6=4)(7=3)(8=2)(9=1)
tab rally
gen dvrally = (rally-1)/8
sum dvrally
tab dvrally

// [DVTOL]: Dependent Varaible, General Tolerance Scale, 0 = Intolerant, 1 = Tolerant
recode tot2 (1=0)(2=1), gen (toler1) 
recode tot3 (1=0)(2=1), gen (toler2)
recode tot4 (1=0)(2=1), gen (toler3)
kr20 toler1 toler2 toler3

gen tolerance = toler1 + toler2 + toler3
sum tolerance , det
gen dvtol = (tolerance)/3
sum dvtol, det

recode tot2 (1=1)(2=0), gen (toler4)
recode tot5 (1=1)(2=0)(3=.), gen (toler5)

msp toler1 toler2 toler3 toler4 toler5
kr20 toler1 toler2 toler3 toler4 toler5

//*** CONTROLS
recode sex (1=0)(2=1)(6=.)(8=.), gen(female)
tab female
recode race (1=1)(2=0)(3=0)(4=0)(5=0)(6=0)(8=.), gen(black)
recode race (1=0)(2=1)(3=0)(4=0)(5=0)(6=0)(8=.), gen(asian)
recode race (1=0)(2=0)(3=1)(4=0)(5=0)(6=0)(8=.), gen(hispanic)
recode race (1=0)(2=0)(3=0)(4=1)(5=0)(6=1)(8=.), gen(nonwhite)
tab black
tab asian
tab hispanic
tab nonwhite
recode pid (1=7)(2=6)(3=5)(5=3)(6=2)(7=1), gen(par)
gen part = (par - 1)/6
egen partM = mean(part)
gen party = part - partM
tab party


//*** INTERACTIONS
gen lpo_cfsXtherm = lpo_cfs*therm
gen lfs_cpoXtherm = lfs_cpo*therm

gen lpo_cfsXthermL = lpo_cfs*thermL
gen lfs_cpoXthermL = lfs_cpo*thermL

gen lpo_cfsXthermH = lpo_cfs*thermH
gen lfs_cpoXthermH = lfs_cpo*thermH

//*** ANALYSES
// NOTE: Condition is the focal qualitative variable of interest.
// Con-Lib feeling thermometer is the moderator variable.
// 2 x 2 on DVRALLY
reg dvrally lfs_cpo therm lfs_cpoXtherm female black asian hispanic nonwhite party

reg dvrally lfs_cpo thermL lfs_cpoXthermL female black asian hispanic nonwhite party

reg dvrally lfs_cpo thermH lfs_cpoXthermH female black asian hispanic nonwhite party


reg dvrally lfs_cpo female black asian hispanic nonwhite party if therm<0
reg dvrally lfs_cpo female black asian hispanic nonwhite party if therm>0


// 2 x 2 on DVTOL

ologit dvtol lfs_cpo therm lfs_cpoXtherm female black asian hispanic nonwhite party

ologit dvtol lfs_cpo thermL lfs_cpoXthermL female black asian hispanic nonwhite party

ologit dvtol lfs_cpo thermH lfs_cpoXthermH female black asian hispanic nonwhite party


ologit dvtol lfs_cpo female black asian hispanic nonwhite party if therm<0
ologit dvtol lfs_cpo female black asian hispanic nonwhite party if therm>0


// Now rerun analyses with 7-point ideology measure instead
gen ideol = (ideo-1)/6
egen ideolM = mean(ideol)
gen ideology = ideol - ideolM
tab ideology
sum ideology

gen ideologyL = ideol
gen ideologyH = ideol-1

gen lpo_cfsXideo = lpo_cfs*ideology
gen lfs_cpoXideo = lfs_cpo*ideology

gen lpo_cfsXideoL = lpo_cfs*ideologyL
gen lfs_cpoXideoL = lfs_cpo*ideologyL

gen lpo_cfsXideoH = lpo_cfs*ideologyH
gen lfs_cpoXideoH = lfs_cpo*ideologyH

// 2 x 2 on DVRALLY
reg dvrally lfs_cpo ideology lfs_cpoXideo female black asian hispanic nonwhite party

reg dvrally lfs_cpo ideologyL lfs_cpoXideoL female black asian hispanic nonwhite party

reg dvrally lfs_cpo ideologyH lfs_cpoXideoH female black asian hispanic nonwhite party


reg dvrally lfs_cpo female black asian hispanic nonwhite party if ideology<0
reg dvrally lfs_cpo female black asian hispanic nonwhite party if ideology>0

// 2 x 2 on DVTOL
ologit dvtol lfs_cpo ideology lfs_cpoXideo female black asian hispanic nonwhite party

ologit dvtol lfs_cpo ideologyL lfs_cpoXideoL female black asian hispanic nonwhite party

ologit dvtol lfs_cpo ideologyH lfs_cpoXideoH female black asian hispanic nonwhite party

ologit lfs_cpo female black asian hispanic nonwhite party if ideology<0
ologit lfs_cpo female black asian hispanic nonwhite party if ideology>0


// Other Analysis -- Values as DV's -- These are the only Things that Work
// For Therm
reg value2 lfs_cpo therm lfs_cpoXtherm female black asian hispanic nonwhite party
reg value3 lfs_cpo therm lfs_cpoXtherm female black asian hispanic nonwhite party

reg value2 lfs_cpo thermL lfs_cpoXthermL female black asian hispanic nonwhite party
reg value2 lfs_cpo therm lfs_cpoXtherm female black asian hispanic nonwhite party
reg value2 lfs_cpo thermH lfs_cpoXthermH female black asian hispanic nonwhite party

reg value3 lfs_cpo thermL lfs_cpoXthermL female black asian hispanic nonwhite party
reg value3 lfs_cpo therm lfs_cpoXtherm female black asian hispanic nonwhite party
reg value3 lfs_cpo thermH lfs_cpoXthermH female black asian hispanic nonwhite party

reg value3 lpo_cfs thermL lpo_cfsXthermL female black asian hispanic nonwhite party
reg value3 lpo_cfs therm lpo_cfsXtherm female black asian hispanic nonwhite party
reg value3 lpo_cfs thermH lpo_cfsXthermH female black asian hispanic nonwhite party

// For 7-point NES Measure
reg value2 lfs_cpo ideologyL lfs_cpoXideoL female black asian hispanic nonwhite party
reg value2 lfs_cpo ideology lfs_cpoXideo female black asian hispanic nonwhite party
reg value2 lfs_cpo ideologyH lfs_cpoXideoH female black asian hispanic nonwhite party

reg value2 lpo_cfs ideologyL lpo_cfsXideoL female black asian hispanic nonwhite party
reg value2 lpo_cfs ideology lpo_cfsXideo female black asian hispanic nonwhite party
reg value2 lpo_cfs ideologyH lpo_cfsXideoH female black asian hispanic nonwhite party

reg value3 lfs_cpo ideologyL lfs_cpoXideoL female black asian hispanic nonwhite party
reg value3 lfs_cpo ideology lfs_cpoXideo female black asian hispanic nonwhite party
reg value3 lfs_cpo ideologyH lfs_cpoXideoH female black asian hispanic nonwhite party

reg value3 lpo_cfs ideologyL lpo_cfsXideoL female black asian hispanic nonwhite party
reg value3 lpo_cfs ideology lpo_cfsXideo female black asian hispanic nonwhite party
reg value3 lpo_cfs ideologyH lpo_cfsXideoH female black asian hispanic nonwhite party

